RcmdrPlugin.UCA-package: RcmdrPlugin.UCA: Some customization to Rcmdr made by R-UCA project
Description
Some extension to Rcmdr (R Commander), randomness test, variance test
for one normal sample and predictions using active model, to teach statistics in a first
university course made by R-UCA project and used at University of
Cadiz (UCA).
All the customizations provides by this package will be propose to be
part of the Rcmdr package.
All the customization included in the Rcmdr package will be dropped from here.